#!/bin/bash
# packager           : Fred. Galusik <fredg> (fredgk~AT~gmail.com)
# source location    : http://goodies.xfce.org/projects/panel-plugins/xfce4-notes-plugin
# last revised       : 14.01.2008

softname='xfce4notesplugin'
softversion='1.6.1'
packageversion='50.1'

arch='i486'
cpu='i686'

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/xfce4-notes-plugin-$softversion.tar.bz2"
src="$buildir/xfce4-notes-plugin-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/bin
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
                |-----handy-ruler------------------------------------------------------|
xfce4notesplugin: xfce4-notes-plugin (Sticky notes application for the Xfce Desktop)
xfce4notesplugin:
xfce4notesplugin: The notes plugin provides you a simple text editor in a little
xfce4notesplugin: window. It is light and doesn’t require lots of memory 
xfce4notesplugin: therefore it is ideal to use for notes.
xfce4notesplugin: Notes are especially useful for temporary stuff.
xfce4notesplugin: The plugin supports multiple notes through a notebook
xfce4notesplugin:
xfce4notesplugin: 
xfce4notesplugin:
xfce4notesplugin:
EOF

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src

# Build
    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
      --prefix=/usr \
      --sysconfdir=/etc \
      --disable-debug \
      --program-prefix="" \
      --program-suffix="" \
      --build=$arch-slackware-linux
      
    make
    make install DESTDIR=$dest

# add 'default' files
    cp -a \
      AUTHORS COPYING ChangeLog README INSTALL NEWS TODO \
      $dest/usr/doc/$softname-$softversion
      
# Strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# ZenBuild
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.tgz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.tgz > $package.md5

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
